All Classes and Interfaces
Class
Description
AcceptDataGrantRequest Marshaller
Access to the resource is denied.
What occurs after a certain event.
The API Gateway API that is the asset.
An AWS Arn.
The configuration for the asset, which can include tags.
The destination for the asset.
Details about the asset.
An asset in AWS Data Exchange is a piece of data (Amazon S3 object) or a means of fulfilling data (Amazon Redshift
datashare or Amazon API Gateway API, AWS Lake Formation data permission, or Amazon S3 data access).
The source of the assets.
A revision destination is the Amazon S3 bucket folder destination to where the export will be sent.
Details of the operation to be performed by the job.
CancelJobRequest Marshaller
The request couldn't be completed because it conflicted with the current state of the resource.
CreateDataGrantRequest MarshallerCreateDataSetRequest MarshallerCreateEventActionRequest MarshallerCreateJobRequest MarshallerCreateRevisionRequest Marshaller
Details of the operation to create an Amazon S3 data access from an S3 bucket.
Details about the response of the operation to create an S3 data access from an S3 bucket.
The LF-tag policy for database resources.
The LF-tag policy and permissions for database resources.
Service client for accessing AWS Data Exchange asynchronously.
A builder for creating an instance of
DataExchangeAsyncClient.The parameters object used to resolve the auth schemes for the DataExchange service.
A builder for a
DataExchangeAuthSchemeParams.An auth scheme provider for DataExchange service.
This includes configuration specific to AWS Data Exchange that is supported by both
DataExchangeClientBuilder
and DataExchangeAsyncClientBuilder.Service client for accessing AWS Data Exchange.
A builder for creating an instance of
DataExchangeClient.The parameters object used to resolve an endpoint for the DataExchange service.
An endpoint provider for DataExchange.
Class to expose the service client settings to the user.
A builder for creating a
DataExchangeServiceClientConfiguration
Information about a data grant.
A data set is an AWS resource with one or more revisions.
Extra details specific to a data update type notification.
DeleteAssetRequest MarshallerDeleteDataGrantRequest MarshallerDeleteDataSetRequest MarshallerDeleteEventActionRequest MarshallerDeleteRevisionRequest Marshaller
Extra details specific to a deprecation type notification.
Information about the job error.
Link between an endpoint property and the
AwsEndpointAttribute it represents.
What occurs to start an action.
An event action is an object that defines the relationship between a specific event and an automated action that will
be taken on behalf of the customer.
Details of the operation to be performed by the job.
Details about the export to Amazon S3 response.
Details of the operation to be performed by the job.
The details of the export to signed URL response.
Details of the operation to be performed by the job.
Details about the export revisions to Amazon S3 response.
Encryption configuration of the export job.
GetAssetRequest MarshallerGetDataGrantRequest MarshallerGetDataSetRequest MarshallerGetEventActionRequest MarshallerGetJobRequest MarshallerGetReceivedDataGrantRequest MarshallerGetRevisionRequest MarshallerIdentifiers for variables declared within the rule engine, e.g.
The request details.
The response details.
Details about the job error.
Details of the operation to be performed by the job.
The details in the response for an import request, including the signed URL and other information.
Details about the assets imported from an AWS Lake Formation tag policy request.
Details from an import AWS Lake Formation tag policy job response.
Details from an import from Amazon Redshift datashare request.
Details from an import from Amazon Redshift datashare response.
Details of the operation to be performed by the job.
Details from an import from Amazon S3 response.
An exception occurred with the service.
AWS Data Exchange Jobs are asynchronous import or export operations used to create or copy assets.
An error that occurred with the job request.
The Amazon Resource Name (ARN) of the AWS KMS key used to encrypt the shared S3 objects.
The AWS Lake Formation data permission asset.
Details about the AWS Lake Formation data permission.
Extra details specific to the affected scope in this LF data set.
Details about the AWS Lake Formation resource (Table or Database) included in the AWS Lake Formation data permission.
A structure that allows an LF-admin to grant permissions on certain conditions.
Details about the LF-tag policy.
Represents the output for the
DataExchangeClient.listDataGrantsPaginator(software.amazon.awssdk.services.dataexchange.model.ListDataGrantsRequest)
operation which is a paginated operation.
Represents the output for the
DataExchangeAsyncClient.listDataGrantsPaginator(software.amazon.awssdk.services.dataexchange.model.ListDataGrantsRequest)
operation which is a paginated operation.ListDataGrantsRequest Marshaller
Represents the output for the
DataExchangeClient.listDataSetRevisionsPaginator(software.amazon.awssdk.services.dataexchange.model.ListDataSetRevisionsRequest)
operation which is a paginated operation.
Represents the output for the
DataExchangeAsyncClient.listDataSetRevisionsPaginator(software.amazon.awssdk.services.dataexchange.model.ListDataSetRevisionsRequest)
operation which is a paginated operation.ListDataSetRevisionsRequest Marshaller
Represents the output for the
DataExchangeClient.listDataSetsPaginator(software.amazon.awssdk.services.dataexchange.model.ListDataSetsRequest)
operation which is a paginated operation.
Represents the output for the
DataExchangeAsyncClient.listDataSetsPaginator(software.amazon.awssdk.services.dataexchange.model.ListDataSetsRequest)
operation which is a paginated operation.ListDataSetsRequest Marshaller
Represents the output for the
DataExchangeClient.listEventActionsPaginator(software.amazon.awssdk.services.dataexchange.model.ListEventActionsRequest)
operation which is a paginated operation.
Represents the output for the
DataExchangeAsyncClient.listEventActionsPaginator(software.amazon.awssdk.services.dataexchange.model.ListEventActionsRequest)
operation which is a paginated operation.ListEventActionsRequest Marshaller
Represents the output for the
DataExchangeClient.listJobsPaginator(software.amazon.awssdk.services.dataexchange.model.ListJobsRequest)
operation which is a paginated operation.
Represents the output for the
DataExchangeAsyncClient.listJobsPaginator(software.amazon.awssdk.services.dataexchange.model.ListJobsRequest)
operation which is a paginated operation.ListJobsRequest Marshaller
Represents the output for the
DataExchangeClient.listReceivedDataGrantsPaginator(software.amazon.awssdk.services.dataexchange.model.ListReceivedDataGrantsRequest)
operation which is a paginated operation.
Represents the output for the
DataExchangeAsyncClient.listReceivedDataGrantsPaginator(software.amazon.awssdk.services.dataexchange.model.ListReceivedDataGrantsRequest)
operation which is a paginated operation.ListReceivedDataGrantsRequest Marshaller
Represents the output for the
DataExchangeClient.listRevisionAssetsPaginator(software.amazon.awssdk.services.dataexchange.model.ListRevisionAssetsRequest)
operation which is a paginated operation.
Represents the output for the
DataExchangeAsyncClient.listRevisionAssetsPaginator(software.amazon.awssdk.services.dataexchange.model.ListRevisionAssetsRequest)
operation which is a paginated operation.ListRevisionAssetsRequest MarshallerListTagsForResourceRequest Marshaller
Extra details specific to this notification.
Details about the origin of the data set.
Information about a received data grant.
The Amazon Redshift datashare asset.
The source of the Amazon Redshift datashare asset.
Extra details specific to the affected scope in this Redshift data set.
The details for the request.
The resource couldn't be found.
Details for the response.
The destination where the assets in the revision will be exported.
A revision is a container for one or more assets.
Information about the published revision.
RevokeRevisionRequest MarshallerRepresents a URL to be used internally for endpoint resolution.
The Amazon S3 data access that is the asset.
Source details for an Amazon S3 data access asset.
Extra details specific to the affected scope in this S3 Data Access data set.
The Amazon S3 object that is the asset.
Object encompassing information about a schema change to a single, particular field, a notification can have up to
100 of these.
Extra details specific to this schema change type notification.
Details about the scope of the notifications such as the affected resources.
SendApiAssetRequest MarshallerSendDataSetNotificationRequest Marshaller
The request has exceeded the quotas imposed by the service.
StartJobRequest Marshaller
The LF-tag policy for a table resource.
The LF-tag policy and permissions that apply to table resources.
A tag consisting of a key-value pair that can be applied to a resource.
TagResourceRequest Marshaller
The limit on the number of requests per second was exceeded.
UntagResourceRequest MarshallerUpdateAssetRequest MarshallerUpdateDataSetRequest MarshallerUpdateEventActionRequest MarshallerUpdateRevisionRequest Marshaller
The request was invalid.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.